package cn.com.ty.lift.business.common;

import cn.com.ty.lift.common.utils.AliyunOSSUtil;
import cn.hutool.core.date.DatePattern;
import cn.hutool.core.util.StrUtil;
import com.fasterxml.jackson.datatype.jsr310.ser.LocalDateSerializer;
import com.fasterxml.jackson.datatype.jsr310.ser.LocalDateTimeSerializer;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.jackson.Jackson2ObjectMapperBuilderCustomizer;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;

import java.time.format.DateTimeFormatter;

/**
 * @author wcz
 * @date 2019/12/3
 * @description
 */
@Configuration
@PropertySource("classpath:system.properties")
public class SystemConfiguration {

    @Value("${aliyun.oss.endpoint}")
    public String endpoint;

    @Value("${aliyun.oss.bucketName}")
    public String bucketName;

    @Value("${aliyun.oss.accessKeySecret}")
    public String accessKeySecret;

    @Value("${aliyun.oss.accessKeyId}")
    public String accessKeyId;

    @Bean
    public AliyunOSSUtil createAliyunOSSUtil(){
        if(StrUtil.isNotBlank(endpoint) && StrUtil.isNotBlank(accessKeyId) && StrUtil.isNotBlank(accessKeySecret)){
            return AliyunOSSUtil.me(endpoint,accessKeyId,accessKeySecret);
        }
        return AliyunOSSUtil.me();
    }

    /**
     * 全局格式化日期
     *
     * @return Jackson2ObjectMapperBuilderCustomizer
     */
    @Bean
    public Jackson2ObjectMapperBuilderCustomizer jsonCustomizer() {
        return builder -> {
            builder.serializers(new LocalDateTimeSerializer(
                    DateTimeFormatter.ofPattern(DatePattern.NORM_DATETIME_PATTERN)));
            builder.serializers(new LocalDateSerializer(DateTimeFormatter.ofPattern(DatePattern.NORM_DATE_PATTERN)));
        };
    }
}
