package cn.com.ty.lift.business.project.controller;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.library.dao.entity.model.BatchUpdateLiftRequest;
import cn.com.ty.lift.business.library.dao.entity.model.SelectBatchPlatformCompanyRequest;
import cn.com.ty.lift.business.library.service.PlatformCompanyLiftRelevanceService;
import cn.com.ty.lift.business.library.service.ProjectLiftRelevanceService;
import cn.com.ty.lift.business.project.dao.entity.Project;
import cn.com.ty.lift.business.project.dao.entity.ProjectUser;
import cn.com.ty.lift.business.project.dao.entity.model.ProjectHistoryRequest;
import cn.com.ty.lift.business.project.dao.entity.model.ProjectIDResponse;
import cn.com.ty.lift.business.project.dao.entity.model.ProjectRequest;
import cn.com.ty.lift.business.project.service.ProjectService;
import cn.com.ty.lift.common.base.ExportRequest;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author bieao
 * @date 2019/11/28
 * @description 项目管理控制层
 */
@RestController
@RequestMapping("project")
public class ProjectController {

    @Resource
    private ProjectService projectService;

    @Resource
    private ProjectLiftRelevanceService projectLiftRelevanceService;

    @Resource
    private PlatformCompanyLiftRelevanceService platformCompanyLiftRelevanceService;

    /**
     * @param request 项目列表查询条件
     * @return RestResponse 项目分页列表结果
     * @description 查询项目列表
     * @date 2019/11/28 4:18 PM
     */
    @PostMapping("list")
    public RestResponse list(@RequestBody ProjectRequest request) {
        return projectService.list(request);
    }

    /**
     * @param request 公司项目查询条件
     * @return RestResponse 公司项目分页列表结果
     * @description 查询公司项目列表
     * @date 2019/12/9 10:32 AM
     */
    @PostMapping("companyList")
    public RestResponse companyList(@RequestBody ProjectRequest request) {
        return projectService.companyList(request);
    }

    /**
     * @param request 项目操作记录查询条件
     * @return RestResponse 项目操作记录分页列表结果
     * @description 查询项目操作记录列表
     * @date 2019/12/2 11:41 AM
     */
    @PostMapping("history/list")
    public RestResponse list(@RequestBody ProjectHistoryRequest request) {
        return projectService.list(request);
    }

    /**
     * @param request projectId 项目ID
     * @return RestResponse userList项目组成员列表
     * @description 查询项目组成员
     * @date 2019/12/13 2:40 PM
     */
    @PostMapping("userList")
    public RestResponse userList(@RequestBody ProjectRequest request) {
        return projectService.userList(request);
    }

    /**
     * @param request regionId 区域id
     * @return RestResponse userList项目组成员列表
     * @description 查询项目组成员
     * @date 2019/12/13 2:40 PM
     */
    @PostMapping("projectIDList")
    public RestResponse projectIDList(@RequestBody ProjectRequest request) {
        Long regionId = request.getRegionId();
        if (regionId == null) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.param.empty"));
        }
        List<ProjectIDResponse> projectIDList = projectService.projectIDList(regionId);
        if (projectIDList.isEmpty()) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.data.empty"));
        }
        return RestResponse.ok(projectIDList, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 项目id
     * @return RestResponse 项目详情
     * @description 查询项目详情
     * @date 2019/12/6 10:51 AM
     */
    @PostMapping("detail")
    public RestResponse detail(@RequestBody ProjectRequest request) {
        if (request.getProjectId() == null) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.param.empty"));
        }
        Project project = projectService.detail(request.getProjectId());
        if (project == null) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.data.empty"));
        }
        return RestResponse.ok(project, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.detail.success"));
    }

    /**
     * @return RestResponse 省、市、区树形结构列表
     * @description 查询省、市、区树形结构列表
     * @date 2019/12/4 10:23 AM
     */
    @PostMapping("area/list")
    public RestResponse areaList() {
        return projectService.areaList();
    }

    /**
     * @param project 新增项目数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("add")
    public RestResponse add(@RequestBody Project project) {
        return projectService.add(project);
    }

    /**
     * @param projectUser 新增维保工数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增维保工
     * @date 2019/12/4 4:44 PM
     */
    @PostMapping("worker/add")
    public RestResponse add(@RequestBody ProjectUser projectUser) {
        return projectService.add(projectUser);
    }

    /**
     * @param project 修改项目数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 修改项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody Project project) {
        return projectService.modify(project);
    }

    /**
     * @param request updateLiftList 电梯id列表
     * @param request operate 0：锁定电梯 1：锁定项目
     * @return 1.成功, 0.失败, 消息描述
     * @description 项目锁定、解锁
     * @date 2019/12/5 4:16 PM
     */
    @PostMapping("lockOrUnlock")
    public RestResponse lockOrUnlock(@RequestBody BatchUpdateLiftRequest request) {
        return projectLiftRelevanceService.lockOrUnlock(request);
    }

    /**
     * @param request liftIdList 电梯id列表
     * @param request projectId 项目id
     * @param request operate 操作 1:恢复服务，2:停止服务，3:继续服务
     * @return 1.成功, 0.失败, 消息描述
     * @description 服务操作
     * @date 2019/12/10 5:42 PM
     */
    @PostMapping("serviceOperate")
    public RestResponse serviceOperate(@RequestBody SelectBatchPlatformCompanyRequest request) {
        return platformCompanyLiftRelevanceService.serviceOperate(request);
    }

    /**
     * @param request 导出项目数据列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 导出项目
     * @date 2019/11/28 4:19 PM
     */
    @PostMapping("export")
    public void export(@RequestBody ExportRequest request) {
        projectService.export(request);
    }
}