package cn.com.ty.lift.system.user.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.user.dao.entity.MtCompanyUser;
import cn.com.ty.lift.system.user.dao.entity.UserApplication;
import cn.com.ty.lift.system.user.dao.entity.model.UserApplyRequest;
import cn.com.ty.lift.system.user.dao.mapper.UserApplicationMapper;
import cn.com.ty.lift.system.user.service.IUserApplicationService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.Date;

/**
 * <p>
 * 用户申请表 服务实现类
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-12-13
 */
@Service
public class UserApplicationService extends ServiceImpl<UserApplicationMapper, UserApplication> implements IUserApplicationService {

    @Autowired
    private MtCompanyUserService mtCompanyUserService;

    @Override
    public RestResponse applyTeam(UserApplyRequest userApplyRequest) {
        //判断用户是否申请过
        UserApplication userApplication = new UserApplication();
        userApplication.setMtCompanyId(userApplyRequest.getCompanyId());
        userApplication.setUserId(userApplyRequest.getUserId());
        //设置申请类型为团队
        userApplication.setType(ApiConstants.ApplicationConstants.APPLY_TYPE_TEAM);
        //审核状态变为待审核
        userApplication.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_WAIT);
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "申请成功");
    }

    @Override
    @Transactional
    public RestResponse teamPass(UserApplyRequest userApplyRequest) {
        //操作者id
        Long operatorId = userApplyRequest.getUserId();
        //加入团队审核通过
        UserApplication userApplication = this.getById(userApplyRequest.getId());
        //1.设置申请信息
        userApplication.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_PASS);
        userApplication.setDealDate(LocalDateTime.now());
        userApplication.setDealUserId(operatorId);
        //2.更新公司用户信息
        Long companyId = userApplication.getMtCompanyId();
        Long userId = userApplication.getUserId();
        //获取公司用户信息
        MtCompanyUser mtCompanyUser = mtCompanyUserService.getOne(new QueryWrapper<MtCompanyUser>()
            .eq("mt_company_id", companyId)
            .eq("user_id", userId)
        );
        //如果公司用户信息不存在，新建信息
        if(mtCompanyUser == null){
            mtCompanyUser = new MtCompanyUser();
            mtCompanyUser.setMtCompanyId(companyId);
            mtCompanyUser.setUserId(userId);
            mtCompanyUser.setCreateUserId(userId);
            mtCompanyUser.setCreateTime(new Date());
        }
        mtCompanyUser.setUpdateTime(new Date());
        mtCompanyUser.setUpdateUserId(userId);
        //设置用户状态在团队中
        mtCompanyUser.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_PASS);

        this.updateById(userApplication);
        mtCompanyUserService.saveOrUpdate(mtCompanyUser);
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "操作成功");
    }

    @Override
    public RestResponse teamFail(UserApplyRequest userApplyRequest) {
        UserApplication userApplication = this.getById(userApplyRequest.getId());
        //设置申请状态为审核不通过
        userApplication.setStatus(ApiConstants.ApplicationConstants.COMPANY_USER_FAIL);
        this.updateById(userApplication);
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "操作成功");
    }
}
